@@ -95,7 +95,7 @@ extern int connected;
 static char *gunique(char *);
 static void proxtrans(const char *cmd, char *local, char *remote);
 static int initconn(void);
-static void ptransfer(const char *direction, long bytes, 
+static void ptransfer(const char *direction, off_t bytes, 
 		      const struct timeval *t0, 
 		      const struct timeval *t1);
 static void tvsub(struct timeval *tdiff, 
@@ -105,6 +105,7 @@ static void abort_remote(FILE *din);
 
 FILE *cin, *cout;
 static FILE *dataconn(const char *);
+static void printbytes(off_t);
 
 char *
 hookup(char *host, int port)
@@ -538,7 +539,7 @@ sendrequest(const char *cmd, char *local, char *remote, int printnames)
 	register int c, d;
 	FILE *volatile fin = 0, *volatile dout = 0;
 	int (*volatile closefunc)(FILE *);
-	volatile long bytes = 0, hashbytes = HASHBYTES;
+	volatile off_t bytes = 0, hashbytes = HASHBYTES;
 	char buf[BUFSIZ], *bufp;
 	const char *volatile lmode;
 	sigjmp_buf jmploc;
@@ -708,8 +709,7 @@ sendrequest(const char *cmd, char *local, char *remote, int printnames)
 				(void) fflush(stdout);
 			}
 			if (tick && (bytes >= hashbytes)) {
-				printf("\rBytes transferred: %ld", bytes);
-				(void) fflush(stdout);
+				printbytes(bytes);
 				while (bytes >= hashbytes)
 					hashbytes += TICKBYTES;
 			}
@@ -723,8 +723,7 @@ sendrequest(const char *cmd, char *local, char *remote, int printnames)
 			(void) fflush(stdout);
 		}
 		if (tick) {
-			(void) printf("\rBytes transferred: %ld\n", bytes);
-			(void) fflush(stdout);
+			printbytes(bytes);
 		}
 		if (c < 0)
 			fprintf(stderr, "local: %s: %s\n", local,
@@ -742,9 +741,7 @@ sendrequest(const char *cmd, char *local, char *remote, int printnames)
 					hashbytes += HASHBYTES;
 				}
 				if (tick && (bytes >= hashbytes)) {
-					(void) printf("\rBytes transferred: %ld",
-						bytes);
-					(void) fflush(stdout);
+					printbytes(bytes);
 					while (bytes >= hashbytes)
 						hashbytes += TICKBYTES;
 				}
@@ -771,8 +768,7 @@ sendrequest(const char *cmd, char *local, char *remote, int printnames)
 			(void) fflush(stdout);
 		}
 		if (tick) {
-			(void) printf("\rBytes transferred: %ld\n", bytes);
-			(void) fflush(stdout);
+			printbytes(bytes);
 		}
 		if (ferror(fin))
 			fprintf(stderr, "local: %s: %s\n", local,
@@ -863,7 +859,7 @@ recvrequest(const char *cmd,
 	int tqcflag = 0;
 	unsigned bufsize;
 	char *buf;
-	volatile long bytes = 0, hashbytes = HASHBYTES;
+	volatile off_t bytes = 0, hashbytes = HASHBYTES;
 	register int c, d;
 	struct timeval start, stop;
 	struct stat st;
@@ -1073,9 +1069,7 @@ recvrequest(const char *cmd,
 				(void) fflush(stdout);
 			}
 			if (tick && (bytes >= hashbytes) && is_retr) {
-				(void) printf("\rBytes transferred: %ld",
-					bytes);
-				(void) fflush(stdout);
+				printbytes(bytes);
 				while (bytes >= hashbytes)
 					hashbytes += TICKBYTES;
 			}
@@ -1088,8 +1082,7 @@ recvrequest(const char *cmd,
 			(void) fflush(stdout);
 		}
 		if (tick && is_retr) {
-			(void) printf("\rBytes transferred: %ld\n", bytes);
-			(void) fflush(stdout);
+			printbytes(bytes);
 		}
 		if (c < 0) {
 			perror("netin");
@@ -1142,9 +1135,7 @@ done:
 					hashbytes += HASHBYTES;
 				}
 				if (tick && (bytes >= hashbytes) && is_retr) {
-					printf("\rBytes transferred: %ld",
-						bytes);
-					fflush(stdout);
+					printbytes(bytes);
 					while (bytes >= hashbytes)
 						hashbytes += TICKBYTES;
 				}
@@ -1175,8 +1166,7 @@ break2:
 			(void) fflush(stdout);
 		}
 		if (tick && is_retr) {
-			(void) printf("\rBytes transferred: %ld\n", bytes);
-			(void) fflush(stdout);
+			printbytes(bytes);
 		}
 		if (bare_lfs) {
 			printf("WARNING! %d bare linefeeds received in ASCII mode\n", bare_lfs);
@@ -1483,7 +1473,7 @@ dataconn(const char *lmode)
 }
 
 static void
-ptransfer(const char *direction, long bytes, 
+ptransfer(const char *direction, off_t bytes, 
 	  const struct timeval *t0, 
 	  const struct timeval *t1)
 {
@@ -1495,8 +1485,8 @@ ptransfer(const char *direction, long bytes,
 		s = td.tv_sec + (td.tv_usec / 1000000.);
 #define	nz(x)	((x) == 0 ? 1 : (x))
 		bs = bytes / nz(s);
-		printf("%ld bytes %s in %.2f secs (%.1f kB/s)\n",
-		    bytes, direction, s, bs / 1024.0);
+		printf("%jd bytes %s in %.2f secs (%.1f kB/s)\n",
+		    (intmax_t) bytes, direction, s, bs / 1024.0);
 	}
 }
 
@@ -1863,6 +1853,13 @@ abort_remote(FILE *din)
 	(void) getreply(0);
 }
 
+static void
+printbytes(off_t bytes)
+{
+	printf("\rBytes transferred: %jd", (intmax_t) bytes);
+	fflush(stdout);
+}
+
 static int
 auth_user(char *u,char *p)
 {
